@@ -118,14 +118,14 @@ glide_draw_check (GtkStyle * style,
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	if (GTK_IS_CHECK_MENU_ITEM(widget)) 
+	if (GE_IS_CHECK_MENU_ITEM(widget)) 
 	{
 		x -= 1;
 		y -= 1;
 		width += 2;
 		height += 2;
 	} 
-	else if (GTK_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellcheck"))
+	else if (GE_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellcheck"))
 	{
 		x -= 1;
 		y -= 1;
@@ -142,10 +142,7 @@ glide_draw_check (GtkStyle * style,
 
 	cairo_fill(canvas);
 
-	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-
-	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget));
-	inconsistent |= (CHECK_DETAIL(detail, "cellcheck") && (shadow == GTK_SHADOW_ETCHED_IN));
+	inconsistent = ge_toggle_get_inconsistent(widget, detail, shadow);
 
 	if ((shadow == GTK_SHADOW_IN) || (inconsistent))
 	{
@@ -240,7 +237,7 @@ glide_draw_option (GtkStyle * style,
 	/***********************************************/
 	/* GTK Special Cases - adjust Size/Offset      */
 	/***********************************************/
-	if (GTK_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellradio"))
+	if (GE_IS_CELL_RENDERER_TOGGLE(widget) || CHECK_DETAIL(detail, "cellradio"))
         {
 		x -= 1;
 		y -= 1;
@@ -254,12 +251,12 @@ glide_draw_option (GtkStyle * style,
 	/***********************************************/
 	check_state = GLIDE_CHECK_OFF;
 
-	if (GTK_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)))
+	if (GE_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)))
 	{
 		check_state = GLIDE_CHECK_INCONSISTENT;
 	}
 
-	if (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget))
+	if (GE_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget))
 	{
 		check_state = GLIDE_CHECK_INCONSISTENT;
 	}
@@ -310,7 +307,7 @@ glide_draw_option (GtkStyle * style,
 
 		if (observe_shadow)
 		{
-			border_type = glide_gtk_shadow(shadow);
+			/*border_type = glide_gtk_shadow(shadow);*/
 
 			/***********************************************/
 			/* Convert Shadow Type To Border Type          */
@@ -407,7 +404,7 @@ glide_draw_arrow (GtkStyle * style,
 
 	if ((CHECK_DETAIL (detail, "vscrollbar"))
 		|| (CHECK_DETAIL (detail, "hscrollbar"))
-		|| IS_SCROLLBAR(widget))
+		|| GE_IS_SCROLLBAR(widget))
 	{
 		if (arrow_type == GTK_ARROW_LEFT)
 		{
@@ -545,7 +542,7 @@ glide_draw_shadow (GtkStyle * style,
 		GObject *combo_parent = G_OBJECT(ge_find_combo_box_widget_parent(widget));
 		GtkWidget *button = g_object_get_data(combo_parent, "button");
 
-		if (GTK_IS_WIDGET(button))
+		if (GE_IS_WIDGET(button))
 		{
 			gtk_widget_queue_draw_area(button, button->allocation.x, button->allocation.y, 
 							button->allocation.width, button->allocation.height);
@@ -565,7 +562,7 @@ glide_draw_shadow (GtkStyle * style,
 		if (((CHECK_DETAIL (detail, "entry"))
 			|| (CHECK_DETAIL (detail, "frame")))
 			&& widget && 
-			((IS_SPIN_BUTTON (widget))
+			((GE_IS_SPIN_BUTTON (widget))
 				|| (ge_is_in_combo_box (widget))))
 		{
 			/* The Combo/ComboBoxEntry button and the SpinButton Steppers should apear
@@ -679,7 +676,7 @@ glide_draw_combobox_button (GtkStyle * style,
 
 		for (child = children; child; child = child->next)
 		{
-			if (GTK_IS_ENTRY(child->data) && GTK_WIDGET_HAS_FOCUS(child->data))
+			if (GE_IS_ENTRY(child->data) && GTK_WIDGET_HAS_FOCUS(child->data))
 			{
 				gtk_widget_style_get (widget, "focus_line_width", &focus_line_width, NULL);
 				gtk_widget_style_get (widget, "focus_padding", &focus_padding, NULL);
@@ -721,7 +718,7 @@ glide_draw_combobox_button (GtkStyle * style,
 	      if (parent_state != GTK_STATE_INSENSITIVE)
                 parent_state = GTK_STATE_NORMAL;
 
-#warning FIXME - gdk_draw_rectangle
+/*#warning FIXME - gdk_draw_rectangle*/
 	      gdk_draw_rectangle (window,
 	      	                  parent_style->base_gc[parent_state],
 			          TRUE, x - 2, y, width + 2, height);
@@ -743,7 +740,7 @@ glide_draw_combobox_button (GtkStyle * style,
         {
           GtkWidget *entry = widget;
 
-	  if (GTK_IS_WIDGET(widget) && GTK_IS_WIDGET(widget->parent) && GTK_IS_ENTRY(GTK_COMBO (widget->parent)->entry))
+	  if (GE_IS_WIDGET(widget) && GE_IS_WIDGET(widget->parent) && GE_IS_ENTRY(GTK_COMBO (widget->parent)->entry))
             {
                entry = GTK_COMBO (widget->parent)->entry;
                gtk_widget_ensure_style(entry);
@@ -751,7 +748,7 @@ glide_draw_combobox_button (GtkStyle * style,
                parent_style = entry->style;
                parent_state = entry->state;
              }
-          else if (GTK_IS_WIDGET(widget->parent))
+          else if (GE_IS_WIDGET(widget->parent))
             {
                entry = widget->parent;
                gtk_widget_ensure_style(entry);
@@ -774,7 +771,7 @@ glide_draw_combobox_button (GtkStyle * style,
             shadow.width = width + 2;
             shadow.height = height;
           
-		#warning FIXME - gdk_rectangle_intersect
+/*		#warning FIXME - gdk_rectangle_intersect*/
            if (area)
               gdk_rectangle_intersect(area, &shadow, &clip);
             else
@@ -819,8 +816,9 @@ glide_draw_combobox_button (GtkStyle * style,
         glide_draw_shadow (style, window, state_type, shadow_type, area,
 		          widget, detail, x + focus, y + thick + focus, width - thick - focus*2, height - 2*thick - focus*2);
 
-//      glide_draw_arrow (style, window, state_type, shadow_type, area, NULL, "comboarrow", GTK_ARROW_DOWN, TRUE,  x + focus + 6, y + thick + focus + 5, width - thick - focus*2 - 12, height - 2*thick - focus*2 - 10);
-
+#if 0
+      glide_draw_arrow (style, window, state_type, shadow_type, area, NULL, "comboarrow", GTK_ARROW_DOWN, TRUE,  x + focus + 6, y + thick + focus + 5, width - thick - focus*2 - 12, height - 2*thick - focus*2 - 10);
+#endif
 	glide_draw_pattern_fill(canvas, DEFAULT_OVERLAY_PATTERN(glide_style, detail,FALSE), x + focus, y + thick + focus, width - thick - focus*2, height - 2*thick - focus*2);
 
       cairo_destroy(canvas);
@@ -852,7 +850,7 @@ glide_draw_combobox_button (GtkStyle * style,
               if (parent_state != GTK_STATE_INSENSITIVE)
                 parent_state = GTK_STATE_NORMAL;
 
-#warning FIXME - gdk_draw_rectangle
+/*#warning FIXME - gdk_draw_rectangle*/
 	      gdk_draw_rectangle (window, parent_style->base_gc[parent_state],
 			          TRUE, x + focus - focus_padding, y + focus - focus_padding, 
                                         width + thick*2 - focus + focus_padding*2, height - focus*2 + focus_padding*2);
@@ -880,7 +878,7 @@ glide_draw_combobox_button (GtkStyle * style,
         {
           GtkWidget *entry = widget;
 
-	  if (GTK_IS_WIDGET(widget) && GTK_IS_WIDGET(widget->parent) && GTK_IS_ENTRY(GTK_COMBO (widget->parent)->entry))
+	  if (GE_IS_WIDGET(widget) && GE_IS_WIDGET(widget->parent) && GE_IS_ENTRY(GTK_COMBO (widget->parent)->entry))
             {
                entry = GTK_COMBO (widget->parent)->entry;
                gtk_widget_ensure_style(entry);
@@ -888,7 +886,7 @@ glide_draw_combobox_button (GtkStyle * style,
                parent_style = entry->style;
                parent_state = entry->state;
              }
-          else if (GTK_IS_WIDGET(widget->parent))
+          else if (GE_IS_WIDGET(widget->parent))
             {
                entry = widget->parent;
                gtk_widget_ensure_style(entry);
@@ -944,8 +942,9 @@ glide_draw_combobox_button (GtkStyle * style,
         glide_draw_shadow (style, window, state_type, shadow_type, area,
 		          widget, detail, x + thick + focus, y + thick + focus, width - thick - focus*2, height - 2*thick - focus*2);
 
-//      glide_draw_arrow (style, window, state_type, shadow_type, area, NULL, "comboarrow", GTK_ARROW_DOWN, TRUE,  x + thick + focus + 6, y + thick + focus + 5, width - thick - focus*2 - 12, height - 2*thick - focus*2 - 10);
-
+#if 0
+      glide_draw_arrow (style, window, state_type, shadow_type, area, NULL, "comboarrow", GTK_ARROW_DOWN, TRUE,  x + thick + focus + 6, y + thick + focus + 5, width - thick - focus*2 - 12, height - 2*thick - focus*2 - 10);
+#endif
 	glide_draw_pattern_fill(canvas, DEFAULT_OVERLAY_PATTERN(glide_style, detail,FALSE), x + thick + focus, y + thick + focus, width - thick - focus*2, height - 2*thick - focus*2);
 
 	cairo_destroy(canvas);
@@ -1228,7 +1227,7 @@ glide_draw_box (GtkStyle * style,
   CHECK_ARGS
   SANITIZE_SIZE
 
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       glide_gtk2_engine_hack_menu_shell_setup(widget);
     }  
@@ -1280,7 +1279,7 @@ glide_draw_box (GtkStyle * style,
     }
   else if ((CHECK_DETAIL (detail, "trough")))
     {
-	if (GTK_IS_SCALE (widget)) 
+	if (GE_IS_SCALE (widget)) 
 	{
 		GtkAdjustment *adjustment;
 		gfloat value = 0;
@@ -1290,7 +1289,7 @@ glide_draw_box (GtkStyle * style,
 		adjustment = gtk_range_get_adjustment(GTK_RANGE(widget));
 		value = gtk_range_get_value(GTK_RANGE(widget));
 
-		if GTK_IS_HSCALE (widget)
+		if GE_IS_HSCALE (widget)
 		{
 			gint w=0;           
 
@@ -1362,24 +1361,24 @@ glide_draw_box (GtkStyle * style,
 }
   else if ((CHECK_DETAIL (detail, "toolbar"))
 	   || (CHECK_DETAIL (detail, "menubar"))
-	   || (IS_BONOBO_TOOLBAR (widget))
+	   || (GE_IS_BONOBO_TOOLBAR (widget))
 	   || (CHECK_DETAIL (detail, "dockitem"))
 	   || (CHECK_DETAIL (detail, "dockitem_bin"))
 	   || (CHECK_DETAIL (detail, "handlebox_bin"))
 	   || (CHECK_DETAIL (detail, "handlebox")))
     {
       if (((CHECK_DETAIL (detail, "dockitem_bin")) && 
-           (IS_BONOBO_DOCK_ITEM(widget))) || 
+           (GE_IS_BONOBO_DOCK_ITEM(widget))) || 
           ((widget) && (ge_is_bonobo_dock_item(widget->parent))))
 	{	  
 	  GList *children = NULL, *child = NULL;
 	  GtkWidget *dockitem = widget;
 	  gboolean has_grip = FALSE, ltr = TRUE;
 	  
-	  if ((!IS_BONOBO_DOCK_ITEM(widget)) && (!IS_BOX(widget)))
+	  if ((!GE_IS_BONOBO_DOCK_ITEM(widget)) && (!GE_IS_BOX(widget)))
 	    dockitem = widget->parent;
 	    
-	  has_grip = IS_CONTAINER(dockitem);
+	  has_grip = GE_IS_CONTAINER(dockitem);
 	  
 	  ltr = (!widget) || (gtk_widget_get_direction (dockitem) == GTK_TEXT_DIR_LTR);
 	  
@@ -1391,7 +1390,7 @@ glide_draw_box (GtkStyle * style,
                           
             for (child = g_list_first(children); child; child = g_list_next(child))
               {
-	        if (IS_BONOBO_DOCK_ITEM_GRIP(child->data))
+	        if (GE_IS_BONOBO_DOCK_ITEM_GRIP(child->data))
                   has_grip = (GTK_WIDGET_VISIBLE(child->data) && 
                               GTK_WIDGET_REALIZED(child->data) && 
                               GTK_WIDGET(child->data)->allocation.width > 1) &&
@@ -1416,9 +1415,9 @@ glide_draw_box (GtkStyle * style,
 	       
    	      GtkOrientation tmp = GTK_ORIENTATION_HORIZONTAL;
  
-	      if IS_HBOX(dockitem)
+	      if GE_IS_HBOX(dockitem)
 	        tmp = GTK_ORIENTATION_VERTICAL;
-	      else if (IS_BONOBO_DOCK_ITEM(dockitem))
+	      else if (GE_IS_BONOBO_DOCK_ITEM(dockitem))
 	        g_object_get (dockitem, "orientation", &tmp, NULL);
  
 	      if (tmp == GTK_ORIENTATION_HORIZONTAL)
@@ -1473,7 +1472,7 @@ glide_draw_box (GtkStyle * style,
 	glide_draw_pattern_fill(canvas, DEFAULT_OVERLAY_PATTERN(glide_style, detail,FALSE), x, y, width, height);
     }
   else if ((CHECK_DETAIL (detail, "bar"))
-	   && (widget && IS_PROGRESS_BAR (widget)))
+	   && (widget && GE_IS_PROGRESS_BAR (widget)))
     { 
 gboolean vertical = TRUE;
 			switch (GTK_PROGRESS_BAR(widget)->orientation) 
@@ -1527,7 +1526,7 @@ gboolean vertical = TRUE;
 
       /* Paint a triangle here instead of in "buttondefault"
          which is drawn _behind_ the current button */
-      if ((CHECK_DETAIL (detail, "button")) && widget && GTK_WIDGET_HAS_DEFAULT (widget))
+      if ((CHECK_DETAIL (detail, "button")) && widget && GE_WIDGET_HAS_DEFAULT (widget))
         {
           cairo_save(canvas);
 
@@ -1609,15 +1608,16 @@ glide_draw_flat_box (GtkStyle * style,
           gint width, 
           gint height)
 {
-	#warning FIXME - FINISH draw_flat_box
+	/*#warning FIXME - FINISH draw_flat_box*/
 	if (CHECK_DETAIL(detail, "tooltip"))
 	{
 		GlideStyle *glide_style = GLIDE_STYLE (style);
+		cairo_t *canvas;
 
 		CHECK_ARGS
 		SANITIZE_SIZE
 
-		cairo_t *canvas = ge_gdk_drawable_to_cairo (window, area);
+		canvas = ge_gdk_drawable_to_cairo (window, area);
 
 		glide_draw_pattern_fill(canvas, DEFAULT_BACKGROUND_PATTERN(glide_style, state_type, &glide_style->bg_solid[state_type]), 
 						x, y, width, height);
@@ -1684,10 +1684,10 @@ glide_draw_slider (GtkStyle * style,
 	glide_draw_pattern_fill(canvas,DEFAULT_BACKGROUND_PATTERN(glide_style, state_type, &glide_style->bg_gradient[orientation == GTK_ORIENTATION_VERTICAL][state_type]), x, y, width, height);
 
 	do_glide_draw_border(canvas, &glide_style->color_cube.bg[state_type],
-				(IS_SCROLLBAR(widget))?GLIDE_BEVEL_STYLE_SMOOTHER:GLIDE_BEVEL_STYLE_DEFAULT, GLIDE_BORDER_TYPE_OUT,
+				(GE_IS_SCROLLBAR(widget))?GLIDE_BEVEL_STYLE_SMOOTHER:GLIDE_BEVEL_STYLE_DEFAULT, GLIDE_BORDER_TYPE_OUT,
 				x, y, width, height);
 
-	if (!IS_SCALE(widget))
+	if (!GE_IS_SCALE(widget))
 	{
 		do_glide_draw_grip (canvas,
 					&glide_style->color_cube.light[state_type],
@@ -1868,7 +1868,6 @@ glide_draw_shadow_gap (GtkStyle * style,
 	/* Draw Border                                 */
 	/***********************************************/
 	bevel_style = GLIDE_BEVEL_STYLE_DEFAULT;
-//	inner_overlap = (((gap_side==GTK_POS_RIGHT) || (gap_side==GTK_POS_BOTTOM)) && (gap_pos==0));
 
 	canvas = ge_gdk_drawable_to_cairo (window, area);
 
@@ -1938,7 +1937,7 @@ glide_draw_extension (GtkStyle * style,
 		To fake the apearance of overlap on edge aligned tabs
 		increase clip by one on gap side. */
 
-	if (widget && (GTK_IS_NOTEBOOK (widget)))
+	if (widget && (GE_IS_NOTEBOOK (widget)))
 	{
 		widget_x = (widget->allocation.x + GTK_CONTAINER (widget)->border_width);
 		widget_y = (widget->allocation.y + GTK_CONTAINER (widget)->border_width);
@@ -1948,7 +1947,7 @@ glide_draw_extension (GtkStyle * style,
 
 	pattern = glide_style->bg_solid[state_type];
 
-	if ((widget && GTK_IS_NOTEBOOK (widget)) && (state_type==GTK_STATE_NORMAL))
+	if ((widget && GE_IS_NOTEBOOK (widget)) && (state_type==GTK_STATE_NORMAL))
 	{ 
 		pattern = glide_style->active_tab_gradient[gap_side][state_type];
 		gap_pos = 1;
@@ -1959,7 +1958,7 @@ glide_draw_extension (GtkStyle * style,
 	{
 		case GTK_POS_TOP:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((x==widget_x) || 
 				((x + width) == (widget_x + widget_width)))))
 			{
@@ -1978,7 +1977,7 @@ glide_draw_extension (GtkStyle * style,
 
 		case GTK_POS_LEFT:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((y==widget_y) || 
 				((y + height) == (widget_y + widget_height)))))
 			{
@@ -1998,7 +1997,7 @@ glide_draw_extension (GtkStyle * style,
 		default:
 		case GTK_POS_BOTTOM:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((x==widget_x) || 
 				((x + width) == (widget_x + widget_width)))))
 			{
@@ -2011,7 +2010,7 @@ glide_draw_extension (GtkStyle * style,
 
 		case GTK_POS_RIGHT:
 			if (GTK_CHECK_VERSION(2,10,0) || 
-				((widget && GTK_IS_NOTEBOOK (widget)) && 
+				((widget && GE_IS_NOTEBOOK (widget)) && 
 				((y==widget_y) || 
 				((y + height) == (widget_y + widget_height)))))
 			{
@@ -2123,7 +2122,7 @@ glide_draw_handle (GtkStyle * style,
   CHECK_ARGS
   SANITIZE_SIZE
   
-  if (IS_BONOBO_DOCK_ITEM_GRIP(widget) && 
+  if (GE_IS_BONOBO_DOCK_ITEM_GRIP(widget) && 
      (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) && 
       orientation == (GTK_ORIENTATION_HORIZONTAL))
   {
@@ -2137,7 +2136,7 @@ glide_draw_handle (GtkStyle * style,
 
       canvas = ge_gdk_drawable_to_cairo (window, area);
  
-      if (IS_HANDLE_BOX (widget))
+      if (GE_IS_HANDLE_BOX (widget))
 	{
 	  /* handle box apears to be broken in that
 	   * it doesn't pass the orientation properly,
@@ -2161,7 +2160,7 @@ glide_draw_handle (GtkStyle * style,
       else
 	{
 	  if ((CHECK_DETAIL (detail, "handlebox")
-	       && (!IS_HANDLE_BOX_ITEM (widget))))
+	       && (!GE_IS_HANDLE_BOX_ITEM (widget))))
 	    {
 	      /* panel_applet_frame used by the panel is broken,
 	       * always passes orientation == horizontal 
@@ -2188,13 +2187,13 @@ glide_draw_handle (GtkStyle * style,
 	    }
 	}
 
-	glide_draw_pattern_fill(canvas, DEFAULT_BACKGROUND_PATTERN(glide_style, state_type, (IS_PANED(widget))?&glide_style->bg_solid[state_type]: 
+	glide_draw_pattern_fill(canvas, DEFAULT_BACKGROUND_PATTERN(glide_style, state_type, (GE_IS_PANED(widget))?&glide_style->bg_solid[state_type]: 
 				&glide_style->bg_gradient[orientation == (GTK_ORIENTATION_VERTICAL)][state_type]), x, y, width, height);
 
       if (ge_is_panel_widget_item (widget)
 	  && (CHECK_DETAIL (detail, "handlebox")
-	      && (!IS_HANDLE_BOX_ITEM (widget)))
-	  && (!(IS_HANDLE_BOX (widget))))
+	      && (!GE_IS_HANDLE_BOX_ITEM (widget)))
+	  && (!(GE_IS_HANDLE_BOX (widget))))
 	{
 		/* draw the drag bar */
 		if (orientation == GTK_ORIENTATION_VERTICAL)
@@ -2239,9 +2238,9 @@ glide_draw_handle (GtkStyle * style,
 			&glide_style->color_cube.dark[GTK_STATE_NORMAL],
 			x, y, width, height, orientation == GTK_ORIENTATION_VERTICAL);
 
-          if (IS_BONOBO_DOCK_ITEM_GRIP(widget))
+          if (GE_IS_BONOBO_DOCK_ITEM_GRIP(widget))
             {
-              if IS_BOX(widget->parent)
+              if GE_IS_BOX(widget->parent)
                 {
                   GList *children = NULL, *child = NULL;
  
@@ -2249,7 +2248,7 @@ glide_draw_handle (GtkStyle * style,
               
                   for (child = g_list_first(children); child; child = g_list_next(child))
                     {
-	              if (IS_BOX(child->data))
+	              if (GE_IS_BOX(child->data))
 	                {
 	                  skip_shadow = TRUE;
 	                  child = NULL;
@@ -2261,7 +2260,7 @@ glide_draw_handle (GtkStyle * style,
                 }
             }  
           else
-		skip_shadow = IS_PANED(widget);
+		skip_shadow = GE_IS_PANED(widget);
 
           if (!skip_shadow)
             {
@@ -2330,12 +2329,12 @@ glide_draw_focus(GtkStyle *style,
 
 			entry = g_object_get_data(G_OBJECT(ge_find_combo_box_widget_parent (widget)), "entry");
 
-			if (GTK_IS_WIDGET(entry) && !GTK_WIDGET_HAS_FOCUS(entry))
+			if (GE_IS_WIDGET(entry) && !GTK_WIDGET_HAS_FOCUS(entry))
 			{
 				gtk_widget_grab_focus(entry);
 			}
 		}
-	 	else if (CHECK_DETAIL(detail, "entry") && (IS_SPIN_BUTTON(widget)) )
+	 	else if (CHECK_DETAIL(detail, "entry") && (GE_IS_SPIN_BUTTON(widget)) )
 		{
 			if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR))
 			{
@@ -2350,7 +2349,7 @@ glide_draw_focus(GtkStyle *style,
 		{
 			GtkWidget *button = g_object_get_data(G_OBJECT(ge_find_combo_box_widget_parent (widget)), "button");
 
-			if (GTK_IS_WIDGET(button))
+			if (GE_IS_WIDGET(button))
 			{
 				gtk_widget_queue_draw_area(button, button->allocation.x, button->allocation.y, 
 								button->allocation.width, button->allocation.height);
@@ -2438,7 +2437,7 @@ glide_draw_layout (GtkStyle        *style,
 	CHECK_ARGS
 	use_text &= !ge_is_combo_box(widget, FALSE);
 
-	#warning FIXME - gdk gdk gdk
+/*	#warning FIXME - gdk gdk gdk*/
 
 	gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
 	
