@@ -489,7 +489,7 @@ redmond_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
                       GdkEventMotion *event, 
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       gint pointer_x, pointer_y;
       GdkModifierType pointer_mask;
@@ -497,13 +497,13 @@ redmond_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
      
       gdk_window_get_pointer(widget->window, &pointer_x, &pointer_y, &pointer_mask);
 	    
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_WIDGET(child->data) && 
+	      if ((child->data) && GE_IS_WIDGET(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
@@ -541,20 +541,20 @@ redmond_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
                       GdkEventCrossing *event,
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       GList *children = NULL, *child = NULL;
  
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_MENU_ITEM(child->data) && 
+	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-                  if ((!GTK_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
+                  if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
                          GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
@@ -582,7 +582,7 @@ redmond_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
 void
 redmond_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
@@ -622,7 +622,7 @@ redmond_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
 void
 redmond_gtk2_engine_hack_menu_shell_cleanup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
